<?php
# **********************************************************************************************
# phpLivePacker
#
# Copyright 2013 Christian Bartl (phplivepacker.bartlweb.net)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# This notice must appear in all copies of the script.


# index.php
#
# web based front end
# *********************************************************************************************
?>

<?php
	// include libraries
	require_once "../lib/phplivepacker-lib.php";
	require_once "../lib/browserdetection-lib.php";
	
	// generate object
	$phplivepacker = new phplivepacker('conf/phplivepacker.ini');
	
	// detect browser
	$browserdetection = new browserdetection(null, $phplivepacker->getConfig(null));
	$phplivepacker->setBrowserInformation($browserdetection->getBrowserInformation());
	
	$conf = $phplivepacker->getConfig(null);
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>admin interface - phpLivePacker <?php echo $conf['general']['version']; ?></title>
	<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
	<meta name="robots" content="noindex, nofollow" />
	<link rel="stylesheet" type="text/css" href="css/style.css" />
	<link rel="stylesheet" type="text/css" href="css/admin.css" />
</head>

<body>
    <div id="bw_page">		
	    <div id="bw_content">
	    	
	    	<h1>admin interface - phpLivePacker <?php echo $conf['general']['version']; ?></h1>
	    	<p>
				<a href="../">&lt; back to main page</a>
			</p>
	    	
	    	<h2>// version information</h2>
			<p>
				<?php
					echo 'phpLivePacker ' . $conf['general']['version'];
				?>
			</p>
			
			
			<h2>// secure phpLivePacker in production environment</h2>
			<p>
				Make sure to deny access to the following directories e.g. via htaccess in your production environment.
			</p>
			<ul class="bw_nolist">
				<li>&lt;phplivepacker&gt;/admin</li>
				<li>&lt;phplivepacker&gt;/cache</li>	
				<li>&lt;phplivepacker&gt;/conf</li>	
				<li>&lt;phplivepacker&gt;/lib</li>
			</ul>
			
			
			
			<h2>// check configuration for production environment</h2>
			<ul class="bw_nolist bw_margin_bottom">
				<?php					
					if($conf['debug']['debugMode']) {
						echo '<li class="bw_warning">WARNING: debugMode is enabled</li>';
					} else {
						echo '<li class="bw_success">OK: debugMode is turned off</li>';
					}

					if($conf['debug']['developmentMode']) {
						echo '<li class="bw_warning">WARNING: developmentMode is enabled</li>';
					} else {
						echo '<li class="bw_success">OK: developmentMode is turned off</li>';
					}
					
					echo '<li>&nbsp;</li>';	

					if($conf['output']['gzip']) {
						echo '<li class="bw_success">OK: gzip is enabled</li>';
					} else {
						echo '<li class="bw_warning">WARNING: gzip is turned off</li>';						
					}					
					if($conf['output']['minify_css']) {
						echo '<li class="bw_success">OK: minify_css is enabled</li>';
					} else {
						echo '<li class="bw_warning">WARNING: minify_css is turned off</li>';						
					}					
					if($conf['output']['minify_js']) {
						echo '<li class="bw_success">OK: minify_js is enabled</li>';
					} else {
						echo '<li class="bw_warning">WARNING: minify_js is turned off</li>';						
					}
					
					echo '<li>&nbsp;</li>';	
					
					if($conf['caching']['caching']) {						
						echo '<li class="bw_success">OK: cache is enabled</li>';
					} else {
						echo '<li class="bw_warning">WARNING: cache is disabled</li>';
					}
					
					if($conf['caching']['cachingBrowserInfo']) {						
						echo '<li class="bw_success">OK: cache for browser information is enabled</li>';
					} else {
						echo '<li class="bw_warning">WARNING: cache for browser information is disabled</li>';
					}

					if(!is_writable($conf['caching']['cacheDirectory'])) {
						echo '<li class="bw_error">ERROR: cache-directory is not writeable or does not exist</li>';
					} else {
						echo '<li class="bw_success">OK: cache-directory is writeable</li>';
					}


					echo '<li>&nbsp;</li>';
					
					if($conf['browserDetection']['overrideDetection']) {
						echo '<li class="bw_error">ERROR: browserDetection-Override is enabled</li>';
					} else {
						echo '<li class="bw_success">OK: browserDetection-Override is disabled</li>';
					}

				?>
			</ul>
			
			<h2>// debug information</h2>
			<p>
				baseDir<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				<?php echo htmlspecialchars($phplivepacker->getBaseDir()); ?>
			</p>
			<p>
				file path<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				<?php echo htmlspecialchars(dirname($_SERVER['PHP_SELF'])); ?>
			</p>
			<p>
				$_SERVER['DOCUMENT_ROOT']<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				<?php echo htmlspecialchars($_SERVER['DOCUMENT_ROOT']); ?>
			</p>
			<p>
				$_ENV['OS']<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				<?php if(isset($_ENV['OS'])) { echo htmlspecialchars($_ENV['OS']); } ?>
			</p>
			<p>
				$_SERVER['WINDIR']<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				<?php if(isset($_SERVER['WINDIR'])) { echo htmlspecialchars($_SERVER['WINDIR']); } ?>
			</p>
			
			
			<?php if(is_writable($conf['caching']['cacheDirectory'])) {?>
				<h2>// clear phpLivePacker cache</h2>
				<p>Press the button to clear all css/js files cached by phpLivePacker.</p>
				<p>
					cache directory: <?php echo htmlspecialchars($conf['caching']['cacheDirectory']); ?>
				</p>
			
				<form action="<?php echo $_SERVER['REQUEST_URI'] ?>" method="post">
					<fieldset class="bw_fieldset">
						<div class="bw_submitine">
							
							<input type="submit" class="bw_button" value="clear phpLivePacker cache"  name="clear_cache" />
						</div>
					</fieldset>
				</form>
			<?php } ?>
			
			<?php 
				if(isset($_POST['clear_cache'])) {
					if ($handle = opendir($conf['caching']['cacheDirectory'])) {	    			
	    				while (false !== ($file = readdir($handle))) {
	        				if ($file != "." && $file != ".." && $file != ".htaccess" && $file != ".htpasswd") {
	            				unlink($conf['caching']['cacheDirectory'] . $file);
	        				}
	    				}
	    				closedir($handle);
					}
				
					echo '<div class="bw_success bw_margin_top"><p>phpLivePacker cache successfully cleared!</p></div>';
				}
			?>	

	    </div>
		<div id="bw_logo">
	        <a href="http://phplivepacker.bartlweb.net" title="phpLivePacker - Websites"><img src="img/logo.gif" alt="phpLivePacker"/></a>
    	</div>
    </div>	
</body>
</html>